| Title: | Slick Call Stacks |
|---|---|
| Description: | Better looking call stacks after an error. |
| Authors: | Gabor Csardi [aut, cre] |
| Maintainer: | Gabor Csardi <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.0.9000 |
| Built: | 2026-06-04 09:23:32 UTC |
| Source: | https://github.com/mangothecat/tracer |
base::traceback()
Compared to base::traceback(), tb
shows the stack from top to bottom, the same way as utils::recover(),
shows references to source files in a clickable form (in terminals that support this),
cuts long lines of code,
colors the output nicely (although this is a matter of taste),
can show the source code where the error happened, with syntax highlighting, if the source code is available.
tb(frame = NULL, context = 5) bt(frame = NULL, context = 5)tb(frame = NULL, context = 5) bt(frame = NULL, context = 5)
frame |
If |
context |
Number of source code lines to show before and after the current line. |
bt is an alias to tb.
tracer defines an error handler when loaded, via a call to
options(error = tracer:::dumper). If you overwrite the error handler,
then tb does not work properly. You can reinstate the tracer:::dumper
error handler via an explicit call to options().